# -*- coding: utf-8 -*-


class Width(object):
    wrap = 'wrap'
    fill = 'fill'


class Visibility(object):
    visible = 'visible'
    invisible = 'invisible'
    gone = 'gone'


class Gravity(object):
    left = 'left'
    center = 'center'
    right = 'right'


################ linearlayout ###############3

class Orientation(object):
    # 水平
    horizon = 'horizon'
    # 垂直
    vertical = 'vertical'
