# -*- coding: utf-8 -*-
from terminal_layout.ansi.font import Font


class Fore(object):
    black = Font('black', 'fore', 30)
    red = Font('red', 'fore', 31)
    green = Font('green', 'fore', 32)
    yellow = Font('yellow', 'fore', 33)
    blue = Font('blue', 'fore', 34)
    magenta = Font('magenta', 'fore', 35)
    cyan = Font('cyan', 'fore', 36)
    white = Font('white', 'fore', 37)
    reset = Font('reset', 'fore', 39)

    # these are fairly well supported, but not part of the standard.
    lightblack = Font('lightblack', 'fore', 90)
    lightred = Font('lightred', 'fore', 91)
    lightgreen = Font('lightgreen', 'fore', 92)
    lightyellow = Font('lightyellow', 'fore', 93)
    lightblue = Font('lightblue', 'fore', 94)
    lightmagenta = Font('lightmagenta', 'fore', 95)
    lightcyan = Font('lightcyan', 'fore', 96)
    lightwhite = Font('lightwhite', 'fore', 97)

    # ex_xx only support linux, mac

    ex_black = Font('ex_black', 'fore')
    ex_red = Font('ex_red', 'fore')
    ex_green = Font('ex_green', 'fore')
    ex_yellow = Font('ex_yellow', 'fore')
    ex_blue = Font('ex_blue', 'fore')
    ex_magenta = Font('ex_magenta', 'fore')
    ex_cyan = Font('ex_cyan', 'fore')
    ex_light_gray = Font('ex_light_gray', 'fore')
    ex_dark_gray = Font('ex_dark_gray', 'fore')
    ex_light_red = Font('ex_light_red', 'fore')
    ex_light_green = Font('ex_light_green', 'fore')
    ex_light_yellow = Font('ex_light_yellow', 'fore')
    ex_light_blue = Font('ex_light_blue', 'fore')
    ex_light_magenta = Font('ex_light_magenta', 'fore')
    ex_light_cyan = Font('ex_light_cyan', 'fore')
    ex_white = Font('ex_white', 'fore')
    ex_grey_0 = Font('ex_grey_0', 'fore')
    ex_navy_blue = Font('ex_navy_blue', 'fore')
    ex_dark_blue = Font('ex_dark_blue', 'fore')
    ex_blue_3a = Font('ex_blue_3a', 'fore')
    ex_blue_3b = Font('ex_blue_3b', 'fore')
    ex_blue_1 = Font('ex_blue_1', 'fore')
    ex_dark_green = Font('ex_dark_green', 'fore')
    ex_deep_sky_blue_4a = Font('ex_deep_sky_blue_4a', 'fore')
    ex_deep_sky_blue_4b = Font('ex_deep_sky_blue_4b', 'fore')
    ex_deep_sky_blue_4c = Font('ex_deep_sky_blue_4c', 'fore')
    ex_dodger_blue_3 = Font('ex_dodger_blue_3', 'fore')
    ex_dodger_blue_2 = Font('ex_dodger_blue_2', 'fore')
    ex_green_4 = Font('ex_green_4', 'fore')
    ex_spring_green_4 = Font('ex_spring_green_4', 'fore')
    ex_turquoise_4 = Font('ex_turquoise_4', 'fore')
    ex_deep_sky_blue_3a = Font('ex_deep_sky_blue_3a', 'fore')
    ex_deep_sky_blue_3b = Font('ex_deep_sky_blue_3b', 'fore')
    ex_dodger_blue_1 = Font('ex_dodger_blue_1', 'fore')
    ex_green_3a = Font('ex_green_3a', 'fore')
    ex_spring_green_3a = Font('ex_spring_green_3a', 'fore')
    ex_dark_cyan = Font('ex_dark_cyan', 'fore')
    ex_light_sea_green = Font('ex_light_sea_green', 'fore')
    ex_deep_sky_blue_2 = Font('ex_deep_sky_blue_2', 'fore')
    ex_deep_sky_blue_1 = Font('ex_deep_sky_blue_1', 'fore')
    ex_green_3b = Font('ex_green_3b', 'fore')
    ex_spring_green_3b = Font('ex_spring_green_3b', 'fore')
    ex_spring_green_2a = Font('ex_spring_green_2a', 'fore')
    ex_cyan_3 = Font('ex_cyan_3', 'fore')
    ex_dark_turquoise = Font('ex_dark_turquoise', 'fore')
    ex_turquoise_2 = Font('ex_turquoise_2', 'fore')
    ex_green_1 = Font('ex_green_1', 'fore')
    ex_spring_green_2b = Font('ex_spring_green_2b', 'fore')
    ex_spring_green_1 = Font('ex_spring_green_1', 'fore')
    ex_medium_spring_green = Font('ex_medium_spring_green', 'fore')
    ex_cyan_2 = Font('ex_cyan_2', 'fore')
    ex_cyan_1 = Font('ex_cyan_1', 'fore')
    ex_dark_red_1 = Font('ex_dark_red_1', 'fore')
    ex_deep_pink_4a = Font('ex_deep_pink_4a', 'fore')
    ex_purple_4a = Font('ex_purple_4a', 'fore')
    ex_purple_4b = Font('ex_purple_4b', 'fore')
    ex_purple_3 = Font('ex_purple_3', 'fore')
    ex_blue_violet = Font('ex_blue_violet', 'fore')
    ex_orange_4a = Font('ex_orange_4a', 'fore')
    ex_grey_37 = Font('ex_grey_37', 'fore')
    ex_medium_purple_4 = Font('ex_medium_purple_4', 'fore')
    ex_slate_blue_3a = Font('ex_slate_blue_3a', 'fore')
    ex_slate_blue_3b = Font('ex_slate_blue_3b', 'fore')
    ex_royal_blue_1 = Font('ex_royal_blue_1', 'fore')
    ex_chartreuse_4 = Font('ex_chartreuse_4', 'fore')
    ex_dark_sea_green_4a = Font('ex_dark_sea_green_4a', 'fore')
    ex_pale_turquoise_4 = Font('ex_pale_turquoise_4', 'fore')
    ex_steel_blue = Font('ex_steel_blue', 'fore')
    ex_steel_blue_3 = Font('ex_steel_blue_3', 'fore')
    ex_cornflower_blue = Font('ex_cornflower_blue', 'fore')
    ex_chartreuse_3a = Font('ex_chartreuse_3a', 'fore')
    ex_dark_sea_green_4b = Font('ex_dark_sea_green_4b', 'fore')
    ex_cadet_blue_2 = Font('ex_cadet_blue_2', 'fore')
    ex_cadet_blue_1 = Font('ex_cadet_blue_1', 'fore')
    ex_sky_blue_3 = Font('ex_sky_blue_3', 'fore')
    ex_steel_blue_1a = Font('ex_steel_blue_1a', 'fore')
    ex_chartreuse_3b = Font('ex_chartreuse_3b', 'fore')
    ex_pale_green_3a = Font('ex_pale_green_3a', 'fore')
    ex_sea_green_3 = Font('ex_sea_green_3', 'fore')
    ex_aquamarine_3 = Font('ex_aquamarine_3', 'fore')
    ex_medium_turquoise = Font('ex_medium_turquoise', 'fore')
    ex_steel_blue_1b = Font('ex_steel_blue_1b', 'fore')
    ex_chartreuse_2a = Font('ex_chartreuse_2a', 'fore')
    ex_sea_green_2 = Font('ex_sea_green_2', 'fore')
    ex_sea_green_1a = Font('ex_sea_green_1a', 'fore')
    ex_sea_green_1b = Font('ex_sea_green_1b', 'fore')
    ex_aquamarine_1a = Font('ex_aquamarine_1a', 'fore')
    ex_dark_slate_gray_2 = Font('ex_dark_slate_gray_2', 'fore')
    ex_dark_red_2 = Font('ex_dark_red_2', 'fore')
    ex_deep_pink_4b = Font('ex_deep_pink_4b', 'fore')
    ex_dark_magenta_1 = Font('ex_dark_magenta_1', 'fore')
    ex_dark_magenta_2 = Font('ex_dark_magenta_2', 'fore')
    ex_dark_violet_1a = Font('ex_dark_violet_1a', 'fore')
    ex_purple_1a = Font('ex_purple_1a', 'fore')
    ex_orange_4b = Font('ex_orange_4b', 'fore')
    ex_light_pink_4 = Font('ex_light_pink_4', 'fore')
    ex_plum_4 = Font('ex_plum_4', 'fore')
    ex_medium_purple_3a = Font('ex_medium_purple_3a', 'fore')
    ex_medium_purple_3b = Font('ex_medium_purple_3b', 'fore')
    ex_slate_blue_1 = Font('ex_slate_blue_1', 'fore')
    ex_yellow_4a = Font('ex_yellow_4a', 'fore')
    ex_wheat_4 = Font('ex_wheat_4', 'fore')
    ex_grey_53 = Font('ex_grey_53', 'fore')
    ex_light_slate_grey = Font('ex_light_slate_grey', 'fore')
    ex_medium_purple = Font('ex_medium_purple', 'fore')
    ex_light_slate_blue = Font('ex_light_slate_blue', 'fore')
    ex_yellow_4b = Font('ex_yellow_4b', 'fore')
    ex_dark_olive_green_3a = Font('ex_dark_olive_green_3a', 'fore')
    ex_dark_green_sea = Font('ex_dark_green_sea', 'fore')
    ex_light_sky_blue_3a = Font('ex_light_sky_blue_3a', 'fore')
    ex_light_sky_blue_3b = Font('ex_light_sky_blue_3b', 'fore')
    ex_sky_blue_2 = Font('ex_sky_blue_2', 'fore')
    ex_chartreuse_2b = Font('ex_chartreuse_2b', 'fore')
    ex_dark_olive_green_3b = Font('ex_dark_olive_green_3b', 'fore')
    ex_pale_green_3b = Font('ex_pale_green_3b', 'fore')
    ex_dark_sea_green_3a = Font('ex_dark_sea_green_3a', 'fore')
    ex_dark_slate_gray_3 = Font('ex_dark_slate_gray_3', 'fore')
    ex_sky_blue_1 = Font('ex_sky_blue_1', 'fore')
    ex_chartreuse_1 = Font('ex_chartreuse_1', 'fore')
    ex_light_green_2 = Font('ex_light_green_2', 'fore')
    ex_light_green_3 = Font('ex_light_green_3', 'fore')
    ex_pale_green_1a = Font('ex_pale_green_1a', 'fore')
    ex_aquamarine_1b = Font('ex_aquamarine_1b', 'fore')
    ex_dark_slate_gray_1 = Font('ex_dark_slate_gray_1', 'fore')
    ex_red_3a = Font('ex_red_3a', 'fore')
    ex_deep_pink_4c = Font('ex_deep_pink_4c', 'fore')
    ex_medium_violet_red = Font('ex_medium_violet_red', 'fore')
    ex_magenta_3a = Font('ex_magenta_3a', 'fore')
    ex_dark_violet_1b = Font('ex_dark_violet_1b', 'fore')
    ex_purple_1b = Font('ex_purple_1b', 'fore')
    ex_dark_orange_3a = Font('ex_dark_orange_3a', 'fore')
    ex_indian_red_1a = Font('ex_indian_red_1a', 'fore')
    ex_hot_pink_3a = Font('ex_hot_pink_3a', 'fore')
    ex_medium_orchid_3 = Font('ex_medium_orchid_3', 'fore')
    ex_medium_orchid = Font('ex_medium_orchid', 'fore')
    ex_medium_purple_2a = Font('ex_medium_purple_2a', 'fore')
    ex_dark_goldenrod = Font('ex_dark_goldenrod', 'fore')
    ex_light_salmon_3a = Font('ex_light_salmon_3a', 'fore')
    ex_rosy_brown = Font('ex_rosy_brown', 'fore')
    ex_grey_63 = Font('ex_grey_63', 'fore')
    ex_medium_purple_2b = Font('ex_medium_purple_2b', 'fore')
    ex_medium_purple_1 = Font('ex_medium_purple_1', 'fore')
    ex_gold_3a = Font('ex_gold_3a', 'fore')
    ex_dark_khaki = Font('ex_dark_khaki', 'fore')
    ex_navajo_white_3 = Font('ex_navajo_white_3', 'fore')
    ex_grey_69 = Font('ex_grey_69', 'fore')
    ex_light_steel_blue_3 = Font('ex_light_steel_blue_3', 'fore')
    ex_light_steel_blue = Font('ex_light_steel_blue', 'fore')
    ex_yellow_3a = Font('ex_yellow_3a', 'fore')
    ex_dark_olive_green_3 = Font('ex_dark_olive_green_3', 'fore')
    ex_dark_sea_green_3b = Font('ex_dark_sea_green_3b', 'fore')
    ex_dark_sea_green_2 = Font('ex_dark_sea_green_2', 'fore')
    ex_light_cyan_3 = Font('ex_light_cyan_3', 'fore')
    ex_light_sky_blue_1 = Font('ex_light_sky_blue_1', 'fore')
    ex_green_yellow = Font('ex_green_yellow', 'fore')
    ex_dark_olive_green_2 = Font('ex_dark_olive_green_2', 'fore')
    ex_pale_green_1b = Font('ex_pale_green_1b', 'fore')
    ex_dark_sea_green_5b = Font('ex_dark_sea_green_5b', 'fore')
    ex_dark_sea_green_5a = Font('ex_dark_sea_green_5a', 'fore')
    ex_pale_turquoise_1 = Font('ex_pale_turquoise_1', 'fore')
    ex_red_3b = Font('ex_red_3b', 'fore')
    ex_deep_pink_3a = Font('ex_deep_pink_3a', 'fore')
    ex_deep_pink_3b = Font('ex_deep_pink_3b', 'fore')
    ex_magenta_3b = Font('ex_magenta_3b', 'fore')
    ex_magenta_3c = Font('ex_magenta_3c', 'fore')
    ex_magenta_2a = Font('ex_magenta_2a', 'fore')
    ex_dark_orange_3b = Font('ex_dark_orange_3b', 'fore')
    ex_indian_red_1b = Font('ex_indian_red_1b', 'fore')
    ex_hot_pink_3b = Font('ex_hot_pink_3b', 'fore')
    ex_hot_pink_2 = Font('ex_hot_pink_2', 'fore')
    ex_orchid = Font('ex_orchid', 'fore')
    ex_medium_orchid_1a = Font('ex_medium_orchid_1a', 'fore')
    ex_orange_3 = Font('ex_orange_3', 'fore')
    ex_light_salmon_3b = Font('ex_light_salmon_3b', 'fore')
    ex_light_pink_3 = Font('ex_light_pink_3', 'fore')
    ex_pink_3 = Font('ex_pink_3', 'fore')
    ex_plum_3 = Font('ex_plum_3', 'fore')
    ex_violet = Font('ex_violet', 'fore')
    ex_gold_3b = Font('ex_gold_3b', 'fore')
    ex_light_goldenrod_3 = Font('ex_light_goldenrod_3', 'fore')
    ex_tan = Font('ex_tan', 'fore')
    ex_misty_rose_3 = Font('ex_misty_rose_3', 'fore')
    ex_thistle_3 = Font('ex_thistle_3', 'fore')
    ex_plum_2 = Font('ex_plum_2', 'fore')
    ex_yellow_3b = Font('ex_yellow_3b', 'fore')
    ex_khaki_3 = Font('ex_khaki_3', 'fore')
    ex_light_goldenrod_2a = Font('ex_light_goldenrod_2a', 'fore')
    ex_light_yellow_3 = Font('ex_light_yellow_3', 'fore')
    ex_grey_84 = Font('ex_grey_84', 'fore')
    ex_light_steel_blue_1 = Font('ex_light_steel_blue_1', 'fore')
    ex_yellow_2 = Font('ex_yellow_2', 'fore')
    ex_dark_olive_green_1a = Font('ex_dark_olive_green_1a', 'fore')
    ex_dark_olive_green_1b = Font('ex_dark_olive_green_1b', 'fore')
    ex_dark_sea_green_1 = Font('ex_dark_sea_green_1', 'fore')
    ex_honeydew_2 = Font('ex_honeydew_2', 'fore')
    ex_light_cyan_1 = Font('ex_light_cyan_1', 'fore')
    ex_red_1 = Font('ex_red_1', 'fore')
    ex_deep_pink_2 = Font('ex_deep_pink_2', 'fore')
    ex_deep_pink_1a = Font('ex_deep_pink_1a', 'fore')
    ex_deep_pink_1b = Font('ex_deep_pink_1b', 'fore')
    ex_magenta_2b = Font('ex_magenta_2b', 'fore')
    ex_magenta_1 = Font('ex_magenta_1', 'fore')
    ex_orange_red_1 = Font('ex_orange_red_1', 'fore')
    ex_indian_red_1c = Font('ex_indian_red_1c', 'fore')
    ex_indian_red_1d = Font('ex_indian_red_1d', 'fore')
    ex_hot_pink_1a = Font('ex_hot_pink_1a', 'fore')
    ex_hot_pink_1b = Font('ex_hot_pink_1b', 'fore')
    ex_medium_orchid_1b = Font('ex_medium_orchid_1b', 'fore')
    ex_dark_orange = Font('ex_dark_orange', 'fore')
    ex_salmon_1 = Font('ex_salmon_1', 'fore')
    ex_light_coral = Font('ex_light_coral', 'fore')
    ex_pale_violet_red_1 = Font('ex_pale_violet_red_1', 'fore')
    ex_orchid_2 = Font('ex_orchid_2', 'fore')
    ex_orchid_1 = Font('ex_orchid_1', 'fore')
    ex_orange_1 = Font('ex_orange_1', 'fore')
    ex_sandy_brown = Font('ex_sandy_brown', 'fore')
    ex_light_salmon_1 = Font('ex_light_salmon_1', 'fore')
    ex_light_pink_1 = Font('ex_light_pink_1', 'fore')
    ex_pink_1 = Font('ex_pink_1', 'fore')
    ex_plum_1 = Font('ex_plum_1', 'fore')
    ex_gold_1 = Font('ex_gold_1', 'fore')
    ex_light_goldenrod_2b = Font('ex_light_goldenrod_2b', 'fore')
    ex_light_goldenrod_2c = Font('ex_light_goldenrod_2c', 'fore')
    ex_navajo_white_1 = Font('ex_navajo_white_1', 'fore')
    ex_misty_rose1 = Font('ex_misty_rose1', 'fore')
    ex_thistle_1 = Font('ex_thistle_1', 'fore')
    ex_yellow_1 = Font('ex_yellow_1', 'fore')
    ex_light_goldenrod_1 = Font('ex_light_goldenrod_1', 'fore')
    ex_khaki_1 = Font('ex_khaki_1', 'fore')
    ex_wheat_1 = Font('ex_wheat_1', 'fore')
    ex_cornsilk_1 = Font('ex_cornsilk_1', 'fore')
    ex_grey_100 = Font('ex_grey_100', 'fore')
    ex_grey_3 = Font('ex_grey_3', 'fore')
    ex_grey_7 = Font('ex_grey_7', 'fore')
    ex_grey_11 = Font('ex_grey_11', 'fore')
    ex_grey_15 = Font('ex_grey_15', 'fore')
    ex_grey_19 = Font('ex_grey_19', 'fore')
    ex_grey_23 = Font('ex_grey_23', 'fore')
    ex_grey_27 = Font('ex_grey_27', 'fore')
    ex_grey_30 = Font('ex_grey_30', 'fore')
    ex_grey_35 = Font('ex_grey_35', 'fore')
    ex_grey_39 = Font('ex_grey_39', 'fore')
    ex_grey_42 = Font('ex_grey_42', 'fore')
    ex_grey_46 = Font('ex_grey_46', 'fore')
    ex_grey_50 = Font('ex_grey_50', 'fore')
    ex_grey_54 = Font('ex_grey_54', 'fore')
    ex_grey_58 = Font('ex_grey_58', 'fore')
    ex_grey_62 = Font('ex_grey_62', 'fore')
    ex_grey_66 = Font('ex_grey_66', 'fore')
    ex_grey_70 = Font('ex_grey_70', 'fore')
    ex_grey_74 = Font('ex_grey_74', 'fore')
    ex_grey_78 = Font('ex_grey_78', 'fore')
    ex_grey_82 = Font('ex_grey_82', 'fore')
    ex_grey_85 = Font('ex_grey_85', 'fore')
    ex_grey_89 = Font('ex_grey_89', 'fore')
    ex_grey_93 = Font('ex_grey_93', 'fore')


