# -*- coding: utf-8 -*-
from terminal_layout import *



print('\n[ex]color support linux, osx\n')

ctl = LayoutCtl.quick(TableLayout,
                      [
                          [TextView('', 'fore = ex_black', width=30, fore=Fore.ex_black),
                           TextView('', 'back = ex_black', back=Back.ex_black)],
                          [TextView('', 'fore = ex_red', width=30, fore=Fore.ex_red),
                           TextView('', 'back = ex_red', back=Back.ex_red)],
                          [TextView('', 'fore = ex_green', width=30, fore=Fore.ex_green),
                           TextView('', 'back = ex_green', back=Back.ex_green)],
                          [TextView('', 'fore = ex_yellow', width=30, fore=Fore.ex_yellow),
                           TextView('', 'back = ex_yellow', back=Back.ex_yellow)],
                          [TextView('', 'fore = ex_blue', width=30, fore=Fore.ex_blue),
                           TextView('', 'back = ex_blue', back=Back.ex_blue)],
                          [TextView('', 'fore = ex_magenta', width=30, fore=Fore.ex_magenta),
                           TextView('', 'back = ex_magenta', back=Back.ex_magenta)],
                          [TextView('', 'fore = ex_cyan', width=30, fore=Fore.ex_cyan),
                           TextView('', 'back = ex_cyan', back=Back.ex_cyan)],
                          [TextView('', 'fore = ex_light_gray', width=30, fore=Fore.ex_light_gray),
                           TextView('', 'back = ex_light_gray', back=Back.ex_light_gray)],
                          [TextView('', 'fore = ex_dark_gray', width=30, fore=Fore.ex_dark_gray),
                           TextView('', 'back = ex_dark_gray', back=Back.ex_dark_gray)],
                          [TextView('', 'fore = ex_light_red', width=30, fore=Fore.ex_light_red),
                           TextView('', 'back = ex_light_red', back=Back.ex_light_red)],
                          [TextView('', 'fore = ex_light_green', width=30, fore=Fore.ex_light_green),
                           TextView('', 'back = ex_light_green', back=Back.ex_light_green)],
                          [TextView('', 'fore = ex_light_yellow', width=30, fore=Fore.ex_light_yellow),
                           TextView('', 'back = ex_light_yellow', back=Back.ex_light_yellow)],
                          [TextView('', 'fore = ex_light_blue', width=30, fore=Fore.ex_light_blue),
                           TextView('', 'back = ex_light_blue', back=Back.ex_light_blue)],
                          [TextView('', 'fore = ex_light_magenta', width=30, fore=Fore.ex_light_magenta),
                           TextView('', 'back = ex_light_magenta', back=Back.ex_light_magenta)],
                          [TextView('', 'fore = ex_light_cyan', width=30, fore=Fore.ex_light_cyan),
                           TextView('', 'back = ex_light_cyan', back=Back.ex_light_cyan)],
                          [TextView('', 'fore = ex_white', width=30, fore=Fore.ex_white),
                           TextView('', 'back = ex_white', back=Back.ex_white)],
                          [TextView('', 'fore = ex_grey_0', width=30, fore=Fore.ex_grey_0),
                           TextView('', 'back = ex_grey_0', back=Back.ex_grey_0)],
                          [TextView('', 'fore = ex_navy_blue', width=30, fore=Fore.ex_navy_blue),
                           TextView('', 'back = ex_navy_blue', back=Back.ex_navy_blue)],
                          [TextView('', 'fore = ex_dark_blue', width=30, fore=Fore.ex_dark_blue),
                           TextView('', 'back = ex_dark_blue', back=Back.ex_dark_blue)],
                          [TextView('', 'fore = ex_blue_3a', width=30, fore=Fore.ex_blue_3a),
                           TextView('', 'back = ex_blue_3a', back=Back.ex_blue_3a)],
                          [TextView('', 'fore = ex_blue_3b', width=30, fore=Fore.ex_blue_3b),
                           TextView('', 'back = ex_blue_3b', back=Back.ex_blue_3b)],
                          [TextView('', 'fore = ex_blue_1', width=30, fore=Fore.ex_blue_1),
                           TextView('', 'back = ex_blue_1', back=Back.ex_blue_1)],
                          [TextView('', 'fore = ex_dark_green', width=30, fore=Fore.ex_dark_green),
                           TextView('', 'back = ex_dark_green', back=Back.ex_dark_green)],
                          [TextView('', 'fore = ex_deep_sky_blue_4a', width=30, fore=Fore.ex_deep_sky_blue_4a),
                           TextView('', 'back = ex_deep_sky_blue_4a', back=Back.ex_deep_sky_blue_4a)],
                          [TextView('', 'fore = ex_deep_sky_blue_4b', width=30, fore=Fore.ex_deep_sky_blue_4b),
                           TextView('', 'back = ex_deep_sky_blue_4b', back=Back.ex_deep_sky_blue_4b)],
                          [TextView('', 'fore = ex_deep_sky_blue_4c', width=30, fore=Fore.ex_deep_sky_blue_4c),
                           TextView('', 'back = ex_deep_sky_blue_4c', back=Back.ex_deep_sky_blue_4c)],
                          [TextView('', 'fore = ex_dodger_blue_3', width=30, fore=Fore.ex_dodger_blue_3),
                           TextView('', 'back = ex_dodger_blue_3', back=Back.ex_dodger_blue_3)],
                          [TextView('', 'fore = ex_dodger_blue_2', width=30, fore=Fore.ex_dodger_blue_2),
                           TextView('', 'back = ex_dodger_blue_2', back=Back.ex_dodger_blue_2)],
                          [TextView('', 'fore = ex_green_4', width=30, fore=Fore.ex_green_4),
                           TextView('', 'back = ex_green_4', back=Back.ex_green_4)],
                          [TextView('', 'fore = ex_spring_green_4', width=30, fore=Fore.ex_spring_green_4),
                           TextView('', 'back = ex_spring_green_4', back=Back.ex_spring_green_4)],
                          [TextView('', 'fore = ex_turquoise_4', width=30, fore=Fore.ex_turquoise_4),
                           TextView('', 'back = ex_turquoise_4', back=Back.ex_turquoise_4)],
                          [TextView('', 'fore = ex_deep_sky_blue_3a', width=30, fore=Fore.ex_deep_sky_blue_3a),
                           TextView('', 'back = ex_deep_sky_blue_3a', back=Back.ex_deep_sky_blue_3a)],
                          [TextView('', 'fore = ex_deep_sky_blue_3b', width=30, fore=Fore.ex_deep_sky_blue_3b),
                           TextView('', 'back = ex_deep_sky_blue_3b', back=Back.ex_deep_sky_blue_3b)],
                          [TextView('', 'fore = ex_dodger_blue_1', width=30, fore=Fore.ex_dodger_blue_1),
                           TextView('', 'back = ex_dodger_blue_1', back=Back.ex_dodger_blue_1)],
                          [TextView('', 'fore = ex_green_3a', width=30, fore=Fore.ex_green_3a),
                           TextView('', 'back = ex_green_3a', back=Back.ex_green_3a)],
                          [TextView('', 'fore = ex_spring_green_3a', width=30, fore=Fore.ex_spring_green_3a),
                           TextView('', 'back = ex_spring_green_3a', back=Back.ex_spring_green_3a)],
                          [TextView('', 'fore = ex_dark_cyan', width=30, fore=Fore.ex_dark_cyan),
                           TextView('', 'back = ex_dark_cyan', back=Back.ex_dark_cyan)],
                          [TextView('', 'fore = ex_light_sea_green', width=30, fore=Fore.ex_light_sea_green),
                           TextView('', 'back = ex_light_sea_green', back=Back.ex_light_sea_green)],
                          [TextView('', 'fore = ex_deep_sky_blue_2', width=30, fore=Fore.ex_deep_sky_blue_2),
                           TextView('', 'back = ex_deep_sky_blue_2', back=Back.ex_deep_sky_blue_2)],
                          [TextView('', 'fore = ex_deep_sky_blue_1', width=30, fore=Fore.ex_deep_sky_blue_1),
                           TextView('', 'back = ex_deep_sky_blue_1', back=Back.ex_deep_sky_blue_1)],
                          [TextView('', 'fore = ex_green_3b', width=30, fore=Fore.ex_green_3b),
                           TextView('', 'back = ex_green_3b', back=Back.ex_green_3b)],
                          [TextView('', 'fore = ex_spring_green_3b', width=30, fore=Fore.ex_spring_green_3b),
                           TextView('', 'back = ex_spring_green_3b', back=Back.ex_spring_green_3b)],
                          [TextView('', 'fore = ex_spring_green_2a', width=30, fore=Fore.ex_spring_green_2a),
                           TextView('', 'back = ex_spring_green_2a', back=Back.ex_spring_green_2a)],
                          [TextView('', 'fore = ex_cyan_3', width=30, fore=Fore.ex_cyan_3),
                           TextView('', 'back = ex_cyan_3', back=Back.ex_cyan_3)],
                          [TextView('', 'fore = ex_dark_turquoise', width=30, fore=Fore.ex_dark_turquoise),
                           TextView('', 'back = ex_dark_turquoise', back=Back.ex_dark_turquoise)],
                          [TextView('', 'fore = ex_turquoise_2', width=30, fore=Fore.ex_turquoise_2),
                           TextView('', 'back = ex_turquoise_2', back=Back.ex_turquoise_2)],
                          [TextView('', 'fore = ex_green_1', width=30, fore=Fore.ex_green_1),
                           TextView('', 'back = ex_green_1', back=Back.ex_green_1)],
                          [TextView('', 'fore = ex_spring_green_2b', width=30, fore=Fore.ex_spring_green_2b),
                           TextView('', 'back = ex_spring_green_2b', back=Back.ex_spring_green_2b)],
                          [TextView('', 'fore = ex_spring_green_1', width=30, fore=Fore.ex_spring_green_1),
                           TextView('', 'back = ex_spring_green_1', back=Back.ex_spring_green_1)],
                          [TextView('', 'fore = ex_medium_spring_green', width=30, fore=Fore.ex_medium_spring_green),
                           TextView('', 'back = ex_medium_spring_green', back=Back.ex_medium_spring_green)],
                          [TextView('', 'fore = ex_cyan_2', width=30, fore=Fore.ex_cyan_2),
                           TextView('', 'back = ex_cyan_2', back=Back.ex_cyan_2)],
                          [TextView('', 'fore = ex_cyan_1', width=30, fore=Fore.ex_cyan_1),
                           TextView('', 'back = ex_cyan_1', back=Back.ex_cyan_1)],
                          [TextView('', 'fore = ex_dark_red_1', width=30, fore=Fore.ex_dark_red_1),
                           TextView('', 'back = ex_dark_red_1', back=Back.ex_dark_red_1)],
                          [TextView('', 'fore = ex_deep_pink_4a', width=30, fore=Fore.ex_deep_pink_4a),
                           TextView('', 'back = ex_deep_pink_4a', back=Back.ex_deep_pink_4a)],
                          [TextView('', 'fore = ex_purple_4a', width=30, fore=Fore.ex_purple_4a),
                           TextView('', 'back = ex_purple_4a', back=Back.ex_purple_4a)],
                          [TextView('', 'fore = ex_purple_4b', width=30, fore=Fore.ex_purple_4b),
                           TextView('', 'back = ex_purple_4b', back=Back.ex_purple_4b)],
                          [TextView('', 'fore = ex_purple_3', width=30, fore=Fore.ex_purple_3),
                           TextView('', 'back = ex_purple_3', back=Back.ex_purple_3)],
                          [TextView('', 'fore = ex_blue_violet', width=30, fore=Fore.ex_blue_violet),
                           TextView('', 'back = ex_blue_violet', back=Back.ex_blue_violet)],
                          [TextView('', 'fore = ex_orange_4a', width=30, fore=Fore.ex_orange_4a),
                           TextView('', 'back = ex_orange_4a', back=Back.ex_orange_4a)],
                          [TextView('', 'fore = ex_grey_37', width=30, fore=Fore.ex_grey_37),
                           TextView('', 'back = ex_grey_37', back=Back.ex_grey_37)],
                          [TextView('', 'fore = ex_medium_purple_4', width=30, fore=Fore.ex_medium_purple_4),
                           TextView('', 'back = ex_medium_purple_4', back=Back.ex_medium_purple_4)],
                          [TextView('', 'fore = ex_slate_blue_3a', width=30, fore=Fore.ex_slate_blue_3a),
                           TextView('', 'back = ex_slate_blue_3a', back=Back.ex_slate_blue_3a)],
                          [TextView('', 'fore = ex_slate_blue_3b', width=30, fore=Fore.ex_slate_blue_3b),
                           TextView('', 'back = ex_slate_blue_3b', back=Back.ex_slate_blue_3b)],
                          [TextView('', 'fore = ex_royal_blue_1', width=30, fore=Fore.ex_royal_blue_1),
                           TextView('', 'back = ex_royal_blue_1', back=Back.ex_royal_blue_1)],
                          [TextView('', 'fore = ex_chartreuse_4', width=30, fore=Fore.ex_chartreuse_4),
                           TextView('', 'back = ex_chartreuse_4', back=Back.ex_chartreuse_4)],
                          [TextView('', 'fore = ex_dark_sea_green_4a', width=30, fore=Fore.ex_dark_sea_green_4a),
                           TextView('', 'back = ex_dark_sea_green_4a', back=Back.ex_dark_sea_green_4a)],
                          [TextView('', 'fore = ex_pale_turquoise_4', width=30, fore=Fore.ex_pale_turquoise_4),
                           TextView('', 'back = ex_pale_turquoise_4', back=Back.ex_pale_turquoise_4)],
                          [TextView('', 'fore = ex_steel_blue', width=30, fore=Fore.ex_steel_blue),
                           TextView('', 'back = ex_steel_blue', back=Back.ex_steel_blue)],
                          [TextView('', 'fore = ex_steel_blue_3', width=30, fore=Fore.ex_steel_blue_3),
                           TextView('', 'back = ex_steel_blue_3', back=Back.ex_steel_blue_3)],
                          [TextView('', 'fore = ex_cornflower_blue', width=30, fore=Fore.ex_cornflower_blue),
                           TextView('', 'back = ex_cornflower_blue', back=Back.ex_cornflower_blue)],
                          [TextView('', 'fore = ex_chartreuse_3a', width=30, fore=Fore.ex_chartreuse_3a),
                           TextView('', 'back = ex_chartreuse_3a', back=Back.ex_chartreuse_3a)],
                          [TextView('', 'fore = ex_dark_sea_green_4b', width=30, fore=Fore.ex_dark_sea_green_4b),
                           TextView('', 'back = ex_dark_sea_green_4b', back=Back.ex_dark_sea_green_4b)],
                          [TextView('', 'fore = ex_cadet_blue_2', width=30, fore=Fore.ex_cadet_blue_2),
                           TextView('', 'back = ex_cadet_blue_2', back=Back.ex_cadet_blue_2)],
                          [TextView('', 'fore = ex_cadet_blue_1', width=30, fore=Fore.ex_cadet_blue_1),
                           TextView('', 'back = ex_cadet_blue_1', back=Back.ex_cadet_blue_1)],
                          [TextView('', 'fore = ex_sky_blue_3', width=30, fore=Fore.ex_sky_blue_3),
                           TextView('', 'back = ex_sky_blue_3', back=Back.ex_sky_blue_3)],
                          [TextView('', 'fore = ex_steel_blue_1a', width=30, fore=Fore.ex_steel_blue_1a),
                           TextView('', 'back = ex_steel_blue_1a', back=Back.ex_steel_blue_1a)],
                          [TextView('', 'fore = ex_chartreuse_3b', width=30, fore=Fore.ex_chartreuse_3b),
                           TextView('', 'back = ex_chartreuse_3b', back=Back.ex_chartreuse_3b)],
                          [TextView('', 'fore = ex_pale_green_3a', width=30, fore=Fore.ex_pale_green_3a),
                           TextView('', 'back = ex_pale_green_3a', back=Back.ex_pale_green_3a)],
                          [TextView('', 'fore = ex_sea_green_3', width=30, fore=Fore.ex_sea_green_3),
                           TextView('', 'back = ex_sea_green_3', back=Back.ex_sea_green_3)],
                          [TextView('', 'fore = ex_aquamarine_3', width=30, fore=Fore.ex_aquamarine_3),
                           TextView('', 'back = ex_aquamarine_3', back=Back.ex_aquamarine_3)],
                          [TextView('', 'fore = ex_medium_turquoise', width=30, fore=Fore.ex_medium_turquoise),
                           TextView('', 'back = ex_medium_turquoise', back=Back.ex_medium_turquoise)],
                          [TextView('', 'fore = ex_steel_blue_1b', width=30, fore=Fore.ex_steel_blue_1b),
                           TextView('', 'back = ex_steel_blue_1b', back=Back.ex_steel_blue_1b)],
                          [TextView('', 'fore = ex_chartreuse_2a', width=30, fore=Fore.ex_chartreuse_2a),
                           TextView('', 'back = ex_chartreuse_2a', back=Back.ex_chartreuse_2a)],
                          [TextView('', 'fore = ex_sea_green_2', width=30, fore=Fore.ex_sea_green_2),
                           TextView('', 'back = ex_sea_green_2', back=Back.ex_sea_green_2)],
                          [TextView('', 'fore = ex_sea_green_1a', width=30, fore=Fore.ex_sea_green_1a),
                           TextView('', 'back = ex_sea_green_1a', back=Back.ex_sea_green_1a)],
                          [TextView('', 'fore = ex_sea_green_1b', width=30, fore=Fore.ex_sea_green_1b),
                           TextView('', 'back = ex_sea_green_1b', back=Back.ex_sea_green_1b)],
                          [TextView('', 'fore = ex_aquamarine_1a', width=30, fore=Fore.ex_aquamarine_1a),
                           TextView('', 'back = ex_aquamarine_1a', back=Back.ex_aquamarine_1a)],
                          [TextView('', 'fore = ex_dark_slate_gray_2', width=30, fore=Fore.ex_dark_slate_gray_2),
                           TextView('', 'back = ex_dark_slate_gray_2', back=Back.ex_dark_slate_gray_2)],
                          [TextView('', 'fore = ex_dark_red_2', width=30, fore=Fore.ex_dark_red_2),
                           TextView('', 'back = ex_dark_red_2', back=Back.ex_dark_red_2)],
                          [TextView('', 'fore = ex_deep_pink_4b', width=30, fore=Fore.ex_deep_pink_4b),
                           TextView('', 'back = ex_deep_pink_4b', back=Back.ex_deep_pink_4b)],
                          [TextView('', 'fore = ex_dark_magenta_1', width=30, fore=Fore.ex_dark_magenta_1),
                           TextView('', 'back = ex_dark_magenta_1', back=Back.ex_dark_magenta_1)],
                          [TextView('', 'fore = ex_dark_magenta_2', width=30, fore=Fore.ex_dark_magenta_2),
                           TextView('', 'back = ex_dark_magenta_2', back=Back.ex_dark_magenta_2)],
                          [TextView('', 'fore = ex_dark_violet_1a', width=30, fore=Fore.ex_dark_violet_1a),
                           TextView('', 'back = ex_dark_violet_1a', back=Back.ex_dark_violet_1a)],
                          [TextView('', 'fore = ex_purple_1a', width=30, fore=Fore.ex_purple_1a),
                           TextView('', 'back = ex_purple_1a', back=Back.ex_purple_1a)],
                          [TextView('', 'fore = ex_orange_4b', width=30, fore=Fore.ex_orange_4b),
                           TextView('', 'back = ex_orange_4b', back=Back.ex_orange_4b)],
                          [TextView('', 'fore = ex_light_pink_4', width=30, fore=Fore.ex_light_pink_4),
                           TextView('', 'back = ex_light_pink_4', back=Back.ex_light_pink_4)],
                          [TextView('', 'fore = ex_plum_4', width=30, fore=Fore.ex_plum_4),
                           TextView('', 'back = ex_plum_4', back=Back.ex_plum_4)],
                          [TextView('', 'fore = ex_medium_purple_3a', width=30, fore=Fore.ex_medium_purple_3a),
                           TextView('', 'back = ex_medium_purple_3a', back=Back.ex_medium_purple_3a)],
                          [TextView('', 'fore = ex_medium_purple_3b', width=30, fore=Fore.ex_medium_purple_3b),
                           TextView('', 'back = ex_medium_purple_3b', back=Back.ex_medium_purple_3b)],
                          [TextView('', 'fore = ex_slate_blue_1', width=30, fore=Fore.ex_slate_blue_1),
                           TextView('', 'back = ex_slate_blue_1', back=Back.ex_slate_blue_1)],
                          [TextView('', 'fore = ex_yellow_4a', width=30, fore=Fore.ex_yellow_4a),
                           TextView('', 'back = ex_yellow_4a', back=Back.ex_yellow_4a)],
                          [TextView('', 'fore = ex_wheat_4', width=30, fore=Fore.ex_wheat_4),
                           TextView('', 'back = ex_wheat_4', back=Back.ex_wheat_4)],
                          [TextView('', 'fore = ex_grey_53', width=30, fore=Fore.ex_grey_53),
                           TextView('', 'back = ex_grey_53', back=Back.ex_grey_53)],
                          [TextView('', 'fore = ex_light_slate_grey', width=30, fore=Fore.ex_light_slate_grey),
                           TextView('', 'back = ex_light_slate_grey', back=Back.ex_light_slate_grey)],
                          [TextView('', 'fore = ex_medium_purple', width=30, fore=Fore.ex_medium_purple),
                           TextView('', 'back = ex_medium_purple', back=Back.ex_medium_purple)],
                          [TextView('', 'fore = ex_light_slate_blue', width=30, fore=Fore.ex_light_slate_blue),
                           TextView('', 'back = ex_light_slate_blue', back=Back.ex_light_slate_blue)],
                          [TextView('', 'fore = ex_yellow_4b', width=30, fore=Fore.ex_yellow_4b),
                           TextView('', 'back = ex_yellow_4b', back=Back.ex_yellow_4b)],
                          [TextView('', 'fore = ex_dark_olive_green_3a', width=30, fore=Fore.ex_dark_olive_green_3a),
                           TextView('', 'back = ex_dark_olive_green_3a', back=Back.ex_dark_olive_green_3a)],
                          [TextView('', 'fore = ex_dark_green_sea', width=30, fore=Fore.ex_dark_green_sea),
                           TextView('', 'back = ex_dark_green_sea', back=Back.ex_dark_green_sea)],
                          [TextView('', 'fore = ex_light_sky_blue_3a', width=30, fore=Fore.ex_light_sky_blue_3a),
                           TextView('', 'back = ex_light_sky_blue_3a', back=Back.ex_light_sky_blue_3a)],
                          [TextView('', 'fore = ex_light_sky_blue_3b', width=30, fore=Fore.ex_light_sky_blue_3b),
                           TextView('', 'back = ex_light_sky_blue_3b', back=Back.ex_light_sky_blue_3b)],
                          [TextView('', 'fore = ex_sky_blue_2', width=30, fore=Fore.ex_sky_blue_2),
                           TextView('', 'back = ex_sky_blue_2', back=Back.ex_sky_blue_2)],
                          [TextView('', 'fore = ex_chartreuse_2b', width=30, fore=Fore.ex_chartreuse_2b),
                           TextView('', 'back = ex_chartreuse_2b', back=Back.ex_chartreuse_2b)],
                          [TextView('', 'fore = ex_dark_olive_green_3b', width=30, fore=Fore.ex_dark_olive_green_3b),
                           TextView('', 'back = ex_dark_olive_green_3b', back=Back.ex_dark_olive_green_3b)],
                          [TextView('', 'fore = ex_pale_green_3b', width=30, fore=Fore.ex_pale_green_3b),
                           TextView('', 'back = ex_pale_green_3b', back=Back.ex_pale_green_3b)],
                          [TextView('', 'fore = ex_dark_sea_green_3a', width=30, fore=Fore.ex_dark_sea_green_3a),
                           TextView('', 'back = ex_dark_sea_green_3a', back=Back.ex_dark_sea_green_3a)],
                          [TextView('', 'fore = ex_dark_slate_gray_3', width=30, fore=Fore.ex_dark_slate_gray_3),
                           TextView('', 'back = ex_dark_slate_gray_3', back=Back.ex_dark_slate_gray_3)],
                          [TextView('', 'fore = ex_sky_blue_1', width=30, fore=Fore.ex_sky_blue_1),
                           TextView('', 'back = ex_sky_blue_1', back=Back.ex_sky_blue_1)],
                          [TextView('', 'fore = ex_chartreuse_1', width=30, fore=Fore.ex_chartreuse_1),
                           TextView('', 'back = ex_chartreuse_1', back=Back.ex_chartreuse_1)],
                          [TextView('', 'fore = ex_light_green_2', width=30, fore=Fore.ex_light_green_2),
                           TextView('', 'back = ex_light_green_2', back=Back.ex_light_green_2)],
                          [TextView('', 'fore = ex_light_green_3', width=30, fore=Fore.ex_light_green_3),
                           TextView('', 'back = ex_light_green_3', back=Back.ex_light_green_3)],
                          [TextView('', 'fore = ex_pale_green_1a', width=30, fore=Fore.ex_pale_green_1a),
                           TextView('', 'back = ex_pale_green_1a', back=Back.ex_pale_green_1a)],
                          [TextView('', 'fore = ex_aquamarine_1b', width=30, fore=Fore.ex_aquamarine_1b),
                           TextView('', 'back = ex_aquamarine_1b', back=Back.ex_aquamarine_1b)],
                          [TextView('', 'fore = ex_dark_slate_gray_1', width=30, fore=Fore.ex_dark_slate_gray_1),
                           TextView('', 'back = ex_dark_slate_gray_1', back=Back.ex_dark_slate_gray_1)],
                          [TextView('', 'fore = ex_red_3a', width=30, fore=Fore.ex_red_3a),
                           TextView('', 'back = ex_red_3a', back=Back.ex_red_3a)],
                          [TextView('', 'fore = ex_deep_pink_4c', width=30, fore=Fore.ex_deep_pink_4c),
                           TextView('', 'back = ex_deep_pink_4c', back=Back.ex_deep_pink_4c)],
                          [TextView('', 'fore = ex_medium_violet_red', width=30, fore=Fore.ex_medium_violet_red),
                           TextView('', 'back = ex_medium_violet_red', back=Back.ex_medium_violet_red)],
                          [TextView('', 'fore = ex_magenta_3a', width=30, fore=Fore.ex_magenta_3a),
                           TextView('', 'back = ex_magenta_3a', back=Back.ex_magenta_3a)],
                          [TextView('', 'fore = ex_dark_violet_1b', width=30, fore=Fore.ex_dark_violet_1b),
                           TextView('', 'back = ex_dark_violet_1b', back=Back.ex_dark_violet_1b)],
                          [TextView('', 'fore = ex_purple_1b', width=30, fore=Fore.ex_purple_1b),
                           TextView('', 'back = ex_purple_1b', back=Back.ex_purple_1b)],
                          [TextView('', 'fore = ex_dark_orange_3a', width=30, fore=Fore.ex_dark_orange_3a),
                           TextView('', 'back = ex_dark_orange_3a', back=Back.ex_dark_orange_3a)],
                          [TextView('', 'fore = ex_indian_red_1a', width=30, fore=Fore.ex_indian_red_1a),
                           TextView('', 'back = ex_indian_red_1a', back=Back.ex_indian_red_1a)],
                          [TextView('', 'fore = ex_hot_pink_3a', width=30, fore=Fore.ex_hot_pink_3a),
                           TextView('', 'back = ex_hot_pink_3a', back=Back.ex_hot_pink_3a)],
                          [TextView('', 'fore = ex_medium_orchid_3', width=30, fore=Fore.ex_medium_orchid_3),
                           TextView('', 'back = ex_medium_orchid_3', back=Back.ex_medium_orchid_3)],
                          [TextView('', 'fore = ex_medium_orchid', width=30, fore=Fore.ex_medium_orchid),
                           TextView('', 'back = ex_medium_orchid', back=Back.ex_medium_orchid)],
                          [TextView('', 'fore = ex_medium_purple_2a', width=30, fore=Fore.ex_medium_purple_2a),
                           TextView('', 'back = ex_medium_purple_2a', back=Back.ex_medium_purple_2a)],
                          [TextView('', 'fore = ex_dark_goldenrod', width=30, fore=Fore.ex_dark_goldenrod),
                           TextView('', 'back = ex_dark_goldenrod', back=Back.ex_dark_goldenrod)],
                          [TextView('', 'fore = ex_light_salmon_3a', width=30, fore=Fore.ex_light_salmon_3a),
                           TextView('', 'back = ex_light_salmon_3a', back=Back.ex_light_salmon_3a)],
                          [TextView('', 'fore = ex_rosy_brown', width=30, fore=Fore.ex_rosy_brown),
                           TextView('', 'back = ex_rosy_brown', back=Back.ex_rosy_brown)],
                          [TextView('', 'fore = ex_grey_63', width=30, fore=Fore.ex_grey_63),
                           TextView('', 'back = ex_grey_63', back=Back.ex_grey_63)],
                          [TextView('', 'fore = ex_medium_purple_2b', width=30, fore=Fore.ex_medium_purple_2b),
                           TextView('', 'back = ex_medium_purple_2b', back=Back.ex_medium_purple_2b)],
                          [TextView('', 'fore = ex_medium_purple_1', width=30, fore=Fore.ex_medium_purple_1),
                           TextView('', 'back = ex_medium_purple_1', back=Back.ex_medium_purple_1)],
                          [TextView('', 'fore = ex_gold_3a', width=30, fore=Fore.ex_gold_3a),
                           TextView('', 'back = ex_gold_3a', back=Back.ex_gold_3a)],
                          [TextView('', 'fore = ex_dark_khaki', width=30, fore=Fore.ex_dark_khaki),
                           TextView('', 'back = ex_dark_khaki', back=Back.ex_dark_khaki)],
                          [TextView('', 'fore = ex_navajo_white_3', width=30, fore=Fore.ex_navajo_white_3),
                           TextView('', 'back = ex_navajo_white_3', back=Back.ex_navajo_white_3)],
                          [TextView('', 'fore = ex_grey_69', width=30, fore=Fore.ex_grey_69),
                           TextView('', 'back = ex_grey_69', back=Back.ex_grey_69)],
                          [TextView('', 'fore = ex_light_steel_blue_3', width=30, fore=Fore.ex_light_steel_blue_3),
                           TextView('', 'back = ex_light_steel_blue_3', back=Back.ex_light_steel_blue_3)],
                          [TextView('', 'fore = ex_light_steel_blue', width=30, fore=Fore.ex_light_steel_blue),
                           TextView('', 'back = ex_light_steel_blue', back=Back.ex_light_steel_blue)],
                          [TextView('', 'fore = ex_yellow_3a', width=30, fore=Fore.ex_yellow_3a),
                           TextView('', 'back = ex_yellow_3a', back=Back.ex_yellow_3a)],
                          [TextView('', 'fore = ex_dark_olive_green_3', width=30, fore=Fore.ex_dark_olive_green_3),
                           TextView('', 'back = ex_dark_olive_green_3', back=Back.ex_dark_olive_green_3)],
                          [TextView('', 'fore = ex_dark_sea_green_3b', width=30, fore=Fore.ex_dark_sea_green_3b),
                           TextView('', 'back = ex_dark_sea_green_3b', back=Back.ex_dark_sea_green_3b)],
                          [TextView('', 'fore = ex_dark_sea_green_2', width=30, fore=Fore.ex_dark_sea_green_2),
                           TextView('', 'back = ex_dark_sea_green_2', back=Back.ex_dark_sea_green_2)],
                          [TextView('', 'fore = ex_light_cyan_3', width=30, fore=Fore.ex_light_cyan_3),
                           TextView('', 'back = ex_light_cyan_3', back=Back.ex_light_cyan_3)],
                          [TextView('', 'fore = ex_light_sky_blue_1', width=30, fore=Fore.ex_light_sky_blue_1),
                           TextView('', 'back = ex_light_sky_blue_1', back=Back.ex_light_sky_blue_1)],
                          [TextView('', 'fore = ex_green_yellow', width=30, fore=Fore.ex_green_yellow),
                           TextView('', 'back = ex_green_yellow', back=Back.ex_green_yellow)],
                          [TextView('', 'fore = ex_dark_olive_green_2', width=30, fore=Fore.ex_dark_olive_green_2),
                           TextView('', 'back = ex_dark_olive_green_2', back=Back.ex_dark_olive_green_2)],
                          [TextView('', 'fore = ex_pale_green_1b', width=30, fore=Fore.ex_pale_green_1b),
                           TextView('', 'back = ex_pale_green_1b', back=Back.ex_pale_green_1b)],
                          [TextView('', 'fore = ex_dark_sea_green_5b', width=30, fore=Fore.ex_dark_sea_green_5b),
                           TextView('', 'back = ex_dark_sea_green_5b', back=Back.ex_dark_sea_green_5b)],
                          [TextView('', 'fore = ex_dark_sea_green_5a', width=30, fore=Fore.ex_dark_sea_green_5a),
                           TextView('', 'back = ex_dark_sea_green_5a', back=Back.ex_dark_sea_green_5a)],
                          [TextView('', 'fore = ex_pale_turquoise_1', width=30, fore=Fore.ex_pale_turquoise_1),
                           TextView('', 'back = ex_pale_turquoise_1', back=Back.ex_pale_turquoise_1)],
                          [TextView('', 'fore = ex_red_3b', width=30, fore=Fore.ex_red_3b),
                           TextView('', 'back = ex_red_3b', back=Back.ex_red_3b)],
                          [TextView('', 'fore = ex_deep_pink_3a', width=30, fore=Fore.ex_deep_pink_3a),
                           TextView('', 'back = ex_deep_pink_3a', back=Back.ex_deep_pink_3a)],
                          [TextView('', 'fore = ex_deep_pink_3b', width=30, fore=Fore.ex_deep_pink_3b),
                           TextView('', 'back = ex_deep_pink_3b', back=Back.ex_deep_pink_3b)],
                          [TextView('', 'fore = ex_magenta_3b', width=30, fore=Fore.ex_magenta_3b),
                           TextView('', 'back = ex_magenta_3b', back=Back.ex_magenta_3b)],
                          [TextView('', 'fore = ex_magenta_3c', width=30, fore=Fore.ex_magenta_3c),
                           TextView('', 'back = ex_magenta_3c', back=Back.ex_magenta_3c)],
                          [TextView('', 'fore = ex_magenta_2a', width=30, fore=Fore.ex_magenta_2a),
                           TextView('', 'back = ex_magenta_2a', back=Back.ex_magenta_2a)],
                          [TextView('', 'fore = ex_dark_orange_3b', width=30, fore=Fore.ex_dark_orange_3b),
                           TextView('', 'back = ex_dark_orange_3b', back=Back.ex_dark_orange_3b)],
                          [TextView('', 'fore = ex_indian_red_1b', width=30, fore=Fore.ex_indian_red_1b),
                           TextView('', 'back = ex_indian_red_1b', back=Back.ex_indian_red_1b)],
                          [TextView('', 'fore = ex_hot_pink_3b', width=30, fore=Fore.ex_hot_pink_3b),
                           TextView('', 'back = ex_hot_pink_3b', back=Back.ex_hot_pink_3b)],
                          [TextView('', 'fore = ex_hot_pink_2', width=30, fore=Fore.ex_hot_pink_2),
                           TextView('', 'back = ex_hot_pink_2', back=Back.ex_hot_pink_2)],
                          [TextView('', 'fore = ex_orchid', width=30, fore=Fore.ex_orchid),
                           TextView('', 'back = ex_orchid', back=Back.ex_orchid)],
                          [TextView('', 'fore = ex_medium_orchid_1a', width=30, fore=Fore.ex_medium_orchid_1a),
                           TextView('', 'back = ex_medium_orchid_1a', back=Back.ex_medium_orchid_1a)],
                          [TextView('', 'fore = ex_orange_3', width=30, fore=Fore.ex_orange_3),
                           TextView('', 'back = ex_orange_3', back=Back.ex_orange_3)],
                          [TextView('', 'fore = ex_light_salmon_3b', width=30, fore=Fore.ex_light_salmon_3b),
                           TextView('', 'back = ex_light_salmon_3b', back=Back.ex_light_salmon_3b)],
                          [TextView('', 'fore = ex_light_pink_3', width=30, fore=Fore.ex_light_pink_3),
                           TextView('', 'back = ex_light_pink_3', back=Back.ex_light_pink_3)],
                          [TextView('', 'fore = ex_pink_3', width=30, fore=Fore.ex_pink_3),
                           TextView('', 'back = ex_pink_3', back=Back.ex_pink_3)],
                          [TextView('', 'fore = ex_plum_3', width=30, fore=Fore.ex_plum_3),
                           TextView('', 'back = ex_plum_3', back=Back.ex_plum_3)],
                          [TextView('', 'fore = ex_violet', width=30, fore=Fore.ex_violet),
                           TextView('', 'back = ex_violet', back=Back.ex_violet)],
                          [TextView('', 'fore = ex_gold_3b', width=30, fore=Fore.ex_gold_3b),
                           TextView('', 'back = ex_gold_3b', back=Back.ex_gold_3b)],
                          [TextView('', 'fore = ex_light_goldenrod_3', width=30, fore=Fore.ex_light_goldenrod_3),
                           TextView('', 'back = ex_light_goldenrod_3', back=Back.ex_light_goldenrod_3)],
                          [TextView('', 'fore = ex_tan', width=30, fore=Fore.ex_tan),
                           TextView('', 'back = ex_tan', back=Back.ex_tan)],
                          [TextView('', 'fore = ex_misty_rose_3', width=30, fore=Fore.ex_misty_rose_3),
                           TextView('', 'back = ex_misty_rose_3', back=Back.ex_misty_rose_3)],
                          [TextView('', 'fore = ex_thistle_3', width=30, fore=Fore.ex_thistle_3),
                           TextView('', 'back = ex_thistle_3', back=Back.ex_thistle_3)],
                          [TextView('', 'fore = ex_plum_2', width=30, fore=Fore.ex_plum_2),
                           TextView('', 'back = ex_plum_2', back=Back.ex_plum_2)],
                          [TextView('', 'fore = ex_yellow_3b', width=30, fore=Fore.ex_yellow_3b),
                           TextView('', 'back = ex_yellow_3b', back=Back.ex_yellow_3b)],
                          [TextView('', 'fore = ex_khaki_3', width=30, fore=Fore.ex_khaki_3),
                           TextView('', 'back = ex_khaki_3', back=Back.ex_khaki_3)],
                          [TextView('', 'fore = ex_light_goldenrod_2a', width=30, fore=Fore.ex_light_goldenrod_2a),
                           TextView('', 'back = ex_light_goldenrod_2a', back=Back.ex_light_goldenrod_2a)],
                          [TextView('', 'fore = ex_light_yellow_3', width=30, fore=Fore.ex_light_yellow_3),
                           TextView('', 'back = ex_light_yellow_3', back=Back.ex_light_yellow_3)],
                          [TextView('', 'fore = ex_grey_84', width=30, fore=Fore.ex_grey_84),
                           TextView('', 'back = ex_grey_84', back=Back.ex_grey_84)],
                          [TextView('', 'fore = ex_light_steel_blue_1', width=30, fore=Fore.ex_light_steel_blue_1),
                           TextView('', 'back = ex_light_steel_blue_1', back=Back.ex_light_steel_blue_1)],
                          [TextView('', 'fore = ex_yellow_2', width=30, fore=Fore.ex_yellow_2),
                           TextView('', 'back = ex_yellow_2', back=Back.ex_yellow_2)],
                          [TextView('', 'fore = ex_dark_olive_green_1a', width=30, fore=Fore.ex_dark_olive_green_1a),
                           TextView('', 'back = ex_dark_olive_green_1a', back=Back.ex_dark_olive_green_1a)],
                          [TextView('', 'fore = ex_dark_olive_green_1b', width=30, fore=Fore.ex_dark_olive_green_1b),
                           TextView('', 'back = ex_dark_olive_green_1b', back=Back.ex_dark_olive_green_1b)],
                          [TextView('', 'fore = ex_dark_sea_green_1', width=30, fore=Fore.ex_dark_sea_green_1),
                           TextView('', 'back = ex_dark_sea_green_1', back=Back.ex_dark_sea_green_1)],
                          [TextView('', 'fore = ex_honeydew_2', width=30, fore=Fore.ex_honeydew_2),
                           TextView('', 'back = ex_honeydew_2', back=Back.ex_honeydew_2)],
                          [TextView('', 'fore = ex_light_cyan_1', width=30, fore=Fore.ex_light_cyan_1),
                           TextView('', 'back = ex_light_cyan_1', back=Back.ex_light_cyan_1)],
                          [TextView('', 'fore = ex_red_1', width=30, fore=Fore.ex_red_1),
                           TextView('', 'back = ex_red_1', back=Back.ex_red_1)],
                          [TextView('', 'fore = ex_deep_pink_2', width=30, fore=Fore.ex_deep_pink_2),
                           TextView('', 'back = ex_deep_pink_2', back=Back.ex_deep_pink_2)],
                          [TextView('', 'fore = ex_deep_pink_1a', width=30, fore=Fore.ex_deep_pink_1a),
                           TextView('', 'back = ex_deep_pink_1a', back=Back.ex_deep_pink_1a)],
                          [TextView('', 'fore = ex_deep_pink_1b', width=30, fore=Fore.ex_deep_pink_1b),
                           TextView('', 'back = ex_deep_pink_1b', back=Back.ex_deep_pink_1b)],
                          [TextView('', 'fore = ex_magenta_2b', width=30, fore=Fore.ex_magenta_2b),
                           TextView('', 'back = ex_magenta_2b', back=Back.ex_magenta_2b)],
                          [TextView('', 'fore = ex_magenta_1', width=30, fore=Fore.ex_magenta_1),
                           TextView('', 'back = ex_magenta_1', back=Back.ex_magenta_1)],
                          [TextView('', 'fore = ex_orange_red_1', width=30, fore=Fore.ex_orange_red_1),
                           TextView('', 'back = ex_orange_red_1', back=Back.ex_orange_red_1)],
                          [TextView('', 'fore = ex_indian_red_1c', width=30, fore=Fore.ex_indian_red_1c),
                           TextView('', 'back = ex_indian_red_1c', back=Back.ex_indian_red_1c)],
                          [TextView('', 'fore = ex_indian_red_1d', width=30, fore=Fore.ex_indian_red_1d),
                           TextView('', 'back = ex_indian_red_1d', back=Back.ex_indian_red_1d)],
                          [TextView('', 'fore = ex_hot_pink_1a', width=30, fore=Fore.ex_hot_pink_1a),
                           TextView('', 'back = ex_hot_pink_1a', back=Back.ex_hot_pink_1a)],
                          [TextView('', 'fore = ex_hot_pink_1b', width=30, fore=Fore.ex_hot_pink_1b),
                           TextView('', 'back = ex_hot_pink_1b', back=Back.ex_hot_pink_1b)],
                          [TextView('', 'fore = ex_medium_orchid_1b', width=30, fore=Fore.ex_medium_orchid_1b),
                           TextView('', 'back = ex_medium_orchid_1b', back=Back.ex_medium_orchid_1b)],
                          [TextView('', 'fore = ex_dark_orange', width=30, fore=Fore.ex_dark_orange),
                           TextView('', 'back = ex_dark_orange', back=Back.ex_dark_orange)],
                          [TextView('', 'fore = ex_salmon_1', width=30, fore=Fore.ex_salmon_1),
                           TextView('', 'back = ex_salmon_1', back=Back.ex_salmon_1)],
                          [TextView('', 'fore = ex_light_coral', width=30, fore=Fore.ex_light_coral),
                           TextView('', 'back = ex_light_coral', back=Back.ex_light_coral)],
                          [TextView('', 'fore = ex_pale_violet_red_1', width=30, fore=Fore.ex_pale_violet_red_1),
                           TextView('', 'back = ex_pale_violet_red_1', back=Back.ex_pale_violet_red_1)],
                          [TextView('', 'fore = ex_orchid_2', width=30, fore=Fore.ex_orchid_2),
                           TextView('', 'back = ex_orchid_2', back=Back.ex_orchid_2)],
                          [TextView('', 'fore = ex_orchid_1', width=30, fore=Fore.ex_orchid_1),
                           TextView('', 'back = ex_orchid_1', back=Back.ex_orchid_1)],
                          [TextView('', 'fore = ex_orange_1', width=30, fore=Fore.ex_orange_1),
                           TextView('', 'back = ex_orange_1', back=Back.ex_orange_1)],
                          [TextView('', 'fore = ex_sandy_brown', width=30, fore=Fore.ex_sandy_brown),
                           TextView('', 'back = ex_sandy_brown', back=Back.ex_sandy_brown)],
                          [TextView('', 'fore = ex_light_salmon_1', width=30, fore=Fore.ex_light_salmon_1),
                           TextView('', 'back = ex_light_salmon_1', back=Back.ex_light_salmon_1)],
                          [TextView('', 'fore = ex_light_pink_1', width=30, fore=Fore.ex_light_pink_1),
                           TextView('', 'back = ex_light_pink_1', back=Back.ex_light_pink_1)],
                          [TextView('', 'fore = ex_pink_1', width=30, fore=Fore.ex_pink_1),
                           TextView('', 'back = ex_pink_1', back=Back.ex_pink_1)],
                          [TextView('', 'fore = ex_plum_1', width=30, fore=Fore.ex_plum_1),
                           TextView('', 'back = ex_plum_1', back=Back.ex_plum_1)],
                          [TextView('', 'fore = ex_gold_1', width=30, fore=Fore.ex_gold_1),
                           TextView('', 'back = ex_gold_1', back=Back.ex_gold_1)],
                          [TextView('', 'fore = ex_light_goldenrod_2b', width=30, fore=Fore.ex_light_goldenrod_2b),
                           TextView('', 'back = ex_light_goldenrod_2b', back=Back.ex_light_goldenrod_2b)],
                          [TextView('', 'fore = ex_light_goldenrod_2c', width=30, fore=Fore.ex_light_goldenrod_2c),
                           TextView('', 'back = ex_light_goldenrod_2c', back=Back.ex_light_goldenrod_2c)],
                          [TextView('', 'fore = ex_navajo_white_1', width=30, fore=Fore.ex_navajo_white_1),
                           TextView('', 'back = ex_navajo_white_1', back=Back.ex_navajo_white_1)],
                          [TextView('', 'fore = ex_misty_rose1', width=30, fore=Fore.ex_misty_rose1),
                           TextView('', 'back = ex_misty_rose1', back=Back.ex_misty_rose1)],
                          [TextView('', 'fore = ex_thistle_1', width=30, fore=Fore.ex_thistle_1),
                           TextView('', 'back = ex_thistle_1', back=Back.ex_thistle_1)],
                          [TextView('', 'fore = ex_yellow_1', width=30, fore=Fore.ex_yellow_1),
                           TextView('', 'back = ex_yellow_1', back=Back.ex_yellow_1)],
                          [TextView('', 'fore = ex_light_goldenrod_1', width=30, fore=Fore.ex_light_goldenrod_1),
                           TextView('', 'back = ex_light_goldenrod_1', back=Back.ex_light_goldenrod_1)],
                          [TextView('', 'fore = ex_khaki_1', width=30, fore=Fore.ex_khaki_1),
                           TextView('', 'back = ex_khaki_1', back=Back.ex_khaki_1)],
                          [TextView('', 'fore = ex_wheat_1', width=30, fore=Fore.ex_wheat_1),
                           TextView('', 'back = ex_wheat_1', back=Back.ex_wheat_1)],
                          [TextView('', 'fore = ex_cornsilk_1', width=30, fore=Fore.ex_cornsilk_1),
                           TextView('', 'back = ex_cornsilk_1', back=Back.ex_cornsilk_1)],
                          [TextView('', 'fore = ex_grey_100', width=30, fore=Fore.ex_grey_100),
                           TextView('', 'back = ex_grey_100', back=Back.ex_grey_100)],
                          [TextView('', 'fore = ex_grey_3', width=30, fore=Fore.ex_grey_3),
                           TextView('', 'back = ex_grey_3', back=Back.ex_grey_3)],
                          [TextView('', 'fore = ex_grey_7', width=30, fore=Fore.ex_grey_7),
                           TextView('', 'back = ex_grey_7', back=Back.ex_grey_7)],
                          [TextView('', 'fore = ex_grey_11', width=30, fore=Fore.ex_grey_11),
                           TextView('', 'back = ex_grey_11', back=Back.ex_grey_11)],
                          [TextView('', 'fore = ex_grey_15', width=30, fore=Fore.ex_grey_15),
                           TextView('', 'back = ex_grey_15', back=Back.ex_grey_15)],
                          [TextView('', 'fore = ex_grey_19', width=30, fore=Fore.ex_grey_19),
                           TextView('', 'back = ex_grey_19', back=Back.ex_grey_19)],
                          [TextView('', 'fore = ex_grey_23', width=30, fore=Fore.ex_grey_23),
                           TextView('', 'back = ex_grey_23', back=Back.ex_grey_23)],
                          [TextView('', 'fore = ex_grey_27', width=30, fore=Fore.ex_grey_27),
                           TextView('', 'back = ex_grey_27', back=Back.ex_grey_27)],
                          [TextView('', 'fore = ex_grey_30', width=30, fore=Fore.ex_grey_30),
                           TextView('', 'back = ex_grey_30', back=Back.ex_grey_30)],
                          [TextView('', 'fore = ex_grey_35', width=30, fore=Fore.ex_grey_35),
                           TextView('', 'back = ex_grey_35', back=Back.ex_grey_35)],
                          [TextView('', 'fore = ex_grey_39', width=30, fore=Fore.ex_grey_39),
                           TextView('', 'back = ex_grey_39', back=Back.ex_grey_39)],
                          [TextView('', 'fore = ex_grey_42', width=30, fore=Fore.ex_grey_42),
                           TextView('', 'back = ex_grey_42', back=Back.ex_grey_42)],
                          [TextView('', 'fore = ex_grey_46', width=30, fore=Fore.ex_grey_46),
                           TextView('', 'back = ex_grey_46', back=Back.ex_grey_46)],
                          [TextView('', 'fore = ex_grey_50', width=30, fore=Fore.ex_grey_50),
                           TextView('', 'back = ex_grey_50', back=Back.ex_grey_50)],
                          [TextView('', 'fore = ex_grey_54', width=30, fore=Fore.ex_grey_54),
                           TextView('', 'back = ex_grey_54', back=Back.ex_grey_54)],
                          [TextView('', 'fore = ex_grey_58', width=30, fore=Fore.ex_grey_58),
                           TextView('', 'back = ex_grey_58', back=Back.ex_grey_58)],
                          [TextView('', 'fore = ex_grey_62', width=30, fore=Fore.ex_grey_62),
                           TextView('', 'back = ex_grey_62', back=Back.ex_grey_62)],
                          [TextView('', 'fore = ex_grey_66', width=30, fore=Fore.ex_grey_66),
                           TextView('', 'back = ex_grey_66', back=Back.ex_grey_66)],
                          [TextView('', 'fore = ex_grey_70', width=30, fore=Fore.ex_grey_70),
                           TextView('', 'back = ex_grey_70', back=Back.ex_grey_70)],
                          [TextView('', 'fore = ex_grey_74', width=30, fore=Fore.ex_grey_74),
                           TextView('', 'back = ex_grey_74', back=Back.ex_grey_74)],
                          [TextView('', 'fore = ex_grey_78', width=30, fore=Fore.ex_grey_78),
                           TextView('', 'back = ex_grey_78', back=Back.ex_grey_78)],
                          [TextView('', 'fore = ex_grey_82', width=30, fore=Fore.ex_grey_82),
                           TextView('', 'back = ex_grey_82', back=Back.ex_grey_82)],
                          [TextView('', 'fore = ex_grey_85', width=30, fore=Fore.ex_grey_85),
                           TextView('', 'back = ex_grey_85', back=Back.ex_grey_85)],
                          [TextView('', 'fore = ex_grey_89', width=30, fore=Fore.ex_grey_89),
                           TextView('', 'back = ex_grey_89', back=Back.ex_grey_89)],
                          [TextView('', 'fore = ex_grey_93', width=30, fore=Fore.ex_grey_93),
                           TextView('', 'back = ex_grey_93', back=Back.ex_grey_93)]
                       ])

ctl.draw(auto_re_draw=False)
